@@ -38,8 +38,10 @@ Color options:
     color_bad: no IPs to show
     color_good: IPs to show
 
-Example:
+Requires:
+    ip: utility found in iproute2 package
 
+Examples:
 ```
 net_iplist {
     iface_blacklist = []
@@ -47,9 +49,6 @@ net_iplist {
 }
 ```
 
-Requires:
-    ip: utility found in iproute2 package
-
 @author guiniol
 
 SAMPLE OUTPUT
@@ -78,7 +77,7 @@ class Py3status:
     remove_empty = True
 
     def post_config_hook(self):
-        self.iface_re = re.compile(r"\d+: (?P<iface>\w+):")
+        self.iface_re = re.compile(r"\d+: (?P<iface>[\w\-]+):")
         self.ip_re = re.compile(r"\s+inet (?P<ip4>[\d\.]+)(?:/| )")
         self.ip6_re = re.compile(r"\s+inet6 (?P<ip6>[\da-f:]+)(?:/| )")
 
